@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/cookie.lisp,v 1.6 2007/01/01 23:50:30 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/cookie.lisp,v 1.7 2007/09/18 14:23:23 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -56,7 +56,15 @@ cookie expires \(or NIL).")
            :initform nil
            :accessor cookie-secure
            :documentation "A generalized boolean denoting whether this
-cookie is a secure cookie."))
+cookie is a secure cookie.")
+   (http-only :initarg :http-only
+              :initform nil
+              :accessor cookie-http-only
+              :documentation "A generalized boolean denoting whether
+this cookie is a `HttpOnly' cookie.
+
+This is a Microsoft extension that has been implemented in Firefox as
+well. See <http://msdn2.microsoft.com/en-us/library/ms533046.aspx>."))
   (:documentation "Each COOKIE objects describes one outgoing cookie."))
 
 (defmethod initialize-instance :around ((cookie cookie) &rest init-args)
@@ -79,7 +87,7 @@ REPLY object REPLY. If a cookie with the same name
         (push (cons name cookie) (cookies-out reply))
         cookie))))
 
-(defun set-cookie (name &key (value "") expires path domain secure (reply *reply*))
+(defun set-cookie (name &key (value "") expires path domain secure http-only (reply *reply*))
   "Creates a cookie object from the parameters provided and adds
 it to the outgoing cookies of the REPLY object REPLY. If a cookie
 with the name NAME \(case-sensitive) already exists, it is
@@ -90,7 +98,8 @@ replaced."
                               :expires expires
                               :path path
                               :domain domain
-                              :secure secure)
+                              :secure secure
+                              :http-only http-only)
                reply))
 
 (defun cookie-date (universal-time)
@@ -102,10 +111,11 @@ replaced."
   "Converts the COOKIE object COOKIE to a string suitable for a
 'Set-Cookie' header to be sent to the client."
   (format nil
-          "~A=~A~:[~;~:*; expires=~A~]~:[~;~:*; path=~A~]~:[~;~:*; domain=~A~]~:[~;; secure~]"
+          "~A=~A~:[~;~:*; expires=~A~]~:[~;~:*; path=~A~]~:[~;~:*; domain=~A~]~:[~;; secure~]~:[~;; HttpOnly~]"
           (cookie-name cookie)
           (url-encode (format nil "~A" (cookie-value cookie)) +utf-8+)
           (cookie-date (cookie-expires cookie))
           (cookie-path cookie)
           (cookie-domain cookie)
-          (cookie-secure cookie)))
\ No newline at end of file
+          (cookie-secure cookie)
+          (cookie-http-only cookie)))
\ No newline at end of file
