@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/headers.lisp,v 1.21 2007/05/25 11:32:50 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/headers.lisp,v 1.24 2007/09/24 13:43:45 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -113,15 +113,18 @@ the stream to write to."
                (setf *close-hunchentoot-stream* nil)
                (when (or (not (eq (server-protocol) :http/1.1))
                          keep-alive-requested-p)
-                 ;; persistent connections are implicitely assumed for
+                 ;; persistent connections are implicitly assumed for
                  ;; HTTP/1.1, but we return a 'Keep-Alive' header if the
-                 ;; client has explicitely asked for one
+                 ;; client has explicitly asked for one
                  (setf (header-out "Connection") "Keep-Alive"
                        (header-out "Keep-Alive")
                        (format nil "timeout=~D" (server-read-timeout *server*)))))
               (t (setf (header-out "Connection") "Close"))))
-      (setf (header-out "Server") (server-name-header)
-            (header-out "Date") (rfc-1123-date)))
+      (unless (and (header-out-set-p "Server")
+                   (null (header-out "Server")))
+        (setf (header-out "Server") (or (header-out "Server")
+                                        (server-name-header))))
+      (setf (header-out "Date") (rfc-1123-date)))
     (unless reason-phrase
       (setq content (escape-for-html
                      (format nil "Unknown http return code: ~A" return-code))
@@ -196,6 +199,7 @@ the stream to write to."
         (write-header-line mod-lisp-p "Content-Type" content-type))
       ;; write all headers from the REPLY object
       (loop for (key . value) in (headers-out)
+            when value
             do (write-header-line mod-lisp-p (string-capitalize key) value))
       ;; now the cookies
       (loop for (nil . cookie) in (cookies-out)
