@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/log.lisp,v 1.8 2007/01/01 23:50:30 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/log.lisp,v 1.9 2007/10/19 23:51:32 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -58,7 +58,9 @@ LOG-LEVEL is a keyword denoting the corresponding Apache error level."
                                 :direction :output
                                 :element-type 'octet
                                 :if-does-not-exist :create
-                                :if-exists :append)))
+                                :if-exists :append
+                                #+:openmcl #+:openmcl
+                                :sharing :lock)))
                      (setq *log-file-stream*
                            (make-flexi-stream log-file-stream
                                               :external-format +utf-8+))))
