@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/misc.lisp,v 1.10 2007/05/07 22:19:13 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/misc.lisp,v 1.11 2007/09/26 06:37:16 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz. All rights reserved.
 
@@ -245,7 +245,10 @@ a 301 request is sent to the browser, otherwise a 302."
                        (ecase protocol
                          ((:http) "http")
                          ((:https) "https"))
-                       host port target))))
+                       (if port                         
+                         (first (ppcre:split ":" (or host "")))
+                         host)
+                       port target))))
     (when add-session-id
       (setq url (add-cookie-value-to-url url :replace-ampersands-p nil)))
     (setf (header-out :location)
@@ -258,7 +261,7 @@ a 301 request is sent to the browser, otherwise a 302."
 
 (defun require-authorization (&optional (realm "Hunchentoot"))
   "Sends back appropriate headers to require basic HTTP authentication
-(see RFC 2617) for the realm REALM."
+\(see RFC 2617) for the realm REALM."
   (setf (header-out "WWW-Authenticate")
           (format nil "Basic realm=\"~A\"" (quote-string realm))
         (return-code *reply*)
