@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-USER; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/packages.lisp,v 1.31 2007/05/25 11:32:51 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/packages.lisp,v 1.33 2007/09/18 14:23:23 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz. All rights reserved.
 
@@ -52,6 +52,8 @@
   (:import-from :lw :with-unique-names :when-let)
   (:export :*approved-return-codes*
            :*catch-errors-p*
+           :*cleanup-function*
+           :*cleanup-interval*
            :*content-types-for-url-rewrite*
            :*default-content-type*
            :*default-handler*
@@ -60,8 +62,6 @@
            :*default-write-timeout*
            :*dispatch-table*
            :*file-upload-hook*
-           :*cleanup-function*
-           :*cleanup-interval*
            :*handle-http-errors-p*
            :*header-stream*
            :*http-error-handler*
@@ -74,6 +74,7 @@
            :*log-lisp-warnings-p*
            :*log-prefix*
            :*meta-dispatcher*
+           :*methods-for-post-parameters*
            :*reply*
            :*request*
            :*rewrite-for-session-urls*
@@ -137,6 +138,7 @@
            :content-type
            :cookie-domain
            :cookie-expires
+           :cookie-http-only
            :cookie-in
            :cookie-name
            :cookie-out
