@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/port-sbcl.lisp,v 1.11 2007/04/04 07:52:06 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/port-sbcl.lisp,v 1.12 2007/09/13 08:35:15 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz. All rights reserved.
 
@@ -58,10 +58,33 @@
 interfer."
   `(with-lock (*incf-mutex*) (incf ,place ,delta)))
 
+;; determine whether SB-EXT:WITH-TIMEOUT is supported; we can't just
+;; use (FIND-SYMBOL "WITH-TIMEOUT" "SB-EXT") because sometimes (for
+;; example in SBCL 1.0.6 for Win32) the function is present, but
+;; doesn't work
+(eval-when (:compile-toplevel :load-toplevel :execute)     
+  (defun ensured-sleep-millis (milliseconds)
+    "Sleeps \(in fact loops) not less then MILLISECONDS number of
+milliseconds; the minimal sleep time is one internal time unit. Don't
+use this function for large time values, because it eats processor
+power."
+    (do ((start-time (get-internal-real-time)))
+        ((< (+ start-time (ceiling (* internal-time-units-per-second 
+                                      (/ milliseconds 1000))))
+            (get-internal-real-time)))))
+  (cl:handler-case
+      (sb-ext:with-timeout 0.0000001 (ensured-sleep-millis 5))
+    (sb-ext:timeout ()
+      (pushnew :hunchentoot-sbcl-with-timeout *features*))
+    (t ())))
+
 (defmacro with-timeout ((seconds &body timeout-forms) &body body)
   "Executes the code BODY and returns the results of the last
 form but stops execution after SECONDS seconds and then instead
 executes the code in TIMEOUT-FORMS."
+  (declare (ignorable seconds timeout-forms body))
+  #-:hunchentoot-sbcl-with-timeout `(cl:progn ,@body)
+  #+:hunchentoot-sbcl-with-timeout
   `(cl:handler-case
      (sb-ext:with-timeout ,seconds ,@body)
      (sb-ext:timeout () ,@timeout-forms)))
