@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/reply.lisp,v 1.18 2007/02/22 08:42:04 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/reply.lisp,v 1.19 2007/09/24 13:43:45 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -112,6 +112,11 @@ handle are defined in specials.lisp."
   "Sets the external format of REPLY."
   (setf (slot-value reply 'external-format) new-value))
 
+(defun header-out-set-p (name &optional (reply *reply*))
+  "Returns a true value if the outgoing http header named NAME has
+been specified already.  NAME should be a keyword or a string."
+  (assoc name (headers-out reply)))
+
 (defun header-out (name &optional (reply *reply*))
   "Returns the current value of the outgoing http header named NAME.
 NAME should be a keyword or a string."
