@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/request.lisp,v 1.31 2007/03/30 17:13:20 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/request.lisp,v 1.33 2007/09/14 12:12:33 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -109,7 +109,11 @@ already been read."
                            (parse-integer content-length-header :junk-allowed t)))
          (content-stream (content-stream request)))
     (setf (slot-value request 'raw-post-data)
-          (cond (want-stream content-stream)
+          (cond (want-stream
+                 (setf (flexi-stream-position *hunchentoot-stream*) 0)
+                 (when content-length
+                   (setf (flexi-stream-bound content-stream) content-length))
+                 content-stream)
                 ((and content-length (> content-length already-read))
                  (decf content-length already-read)
                  (when (input-chunking-p)
@@ -173,7 +177,7 @@ slot values are computed in this :AFTER method."
           ;; if the content-type is 'application/x-www-form-urlencoded'
           ;; or 'multipart/form-data', compute the post parameters from
           ;; the content body
-          (when (eq (request-method request) :post)
+          (when (member (request-method request) *methods-for-post-parameters* :test #'eq)
             (when-let (content-type (cdr (assoc :content-type headers-in)))
               (multiple-value-bind (type subtype external-format)
                   (parse-content-type content-type t)
