@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-USER; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/server.lisp,v 1.35 2007/05/25 11:32:51 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/server.lisp,v 1.37 2007/09/06 23:32:10 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -167,6 +167,7 @@ private key are in one file.  If your private key needs a password you
 can provide it through the SSL-PRIVATEKEY-PASSWORD keyword argument,
 but this works only on LispWorks - for other Lisps the key must not be
 associated with a password."
+  (declare (ignorable port-provided-p))
   ;; initialize the session secret if needed
   (unless (boundp '*session-secret*)
     (reset-session-secret))
@@ -280,7 +281,7 @@ closed or until a read timeout occurs."
                   ;; abort if there's an error which isn't caught inside
                   (lambda (cond)
                     (log-message *lisp-errors-log-level*
-                                 "Error while processing connection: ~A" cond)
+                                 "Error while processing connection: ~A" cond)                    
                     (return-from process-connection)))
                  (warning
                   ;; log all warnings which aren't caught inside
@@ -323,7 +324,9 @@ closed or until a read timeout occurs."
                   (loop
                    (let ((*close-hunchentoot-stream* t))
                      ;; reset to "faithful" format on each iteration
-                     (setf (flexi-stream-external-format *hunchentoot-stream*) +latin-1+)
+                     ;; and reset bound of stream as well
+                     (setf (flexi-stream-external-format *hunchentoot-stream*) +latin-1+
+                           (flexi-stream-bound *hunchentoot-stream*) nil)
                      (multiple-value-bind (headers-in content-stream method url-string server-protocol)
                          (get-request-data)
                        (unless (and ;; check if there was a request at all
