@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/specials.lisp,v 1.29 2007/05/25 16:53:01 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/specials.lisp,v 1.30 2007/09/14 12:12:33 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz. All rights reserved.
 
@@ -178,6 +178,10 @@ which doesn't send correct 'X_FORWARDED_FOR' headers.")
 (defvar *default-content-type* "text/html; charset=iso-8859-1"
   "The default content-type header which is returned to the client.")
 
+(defvar *methods-for-post-parameters* '(:post)
+  "A list of the request method types \(as keywords) for which
+Hunchentoot will try to compute POST-PARAMETERS.")
+
 (defvar *catch-errors-p* t
   "Whether Hunchentoot should catch and log errors \(or rather
 invoke the debugger).")
