@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/unix-sbcl.lisp,v 1.6 2007/01/01 23:50:30 edi Exp $
+;;; $Header: /usr/local/cvsrep/hunchentoot/unix-sbcl.lisp,v 1.7 2007/10/06 22:44:06 edi Exp $
 
 ;;; Copyright (c) 2004-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -29,6 +29,11 @@
 
 (in-package :hunchentoot)
 
+(eval-when (:compile-toplevel :load-toplevel :execute)
+  (when (and (eq (nth-value 1 (find-symbol "GETGRNAM" :sb-posix)) :external)
+             (eq (nth-value 1 (find-symbol "GROUP-GID" :sb-posix)) :external))
+    (pushnew :sb-posix-has-getgrnam *features*)))
+
 (defun setuid (uid)
   "Sets the effective user ID of the current process to UID - see
 setuid\(2)."
@@ -45,5 +50,8 @@ see setgid\(2)."
 
 (defun get-gid-from-name (name)
   "Returns the GID for the group named NAME."
-  (declare (ignore name))
-  (error "GET-GID-FROM-NAME not yet implemented for SBCL.  Please send patches..."))
+  (declare (ignorable name))
+  #+:sb-posix-has-getgrnam
+  (sb-posix:group-gid (sb-posix:getgrnam name))
+  #-:sb-posix-has-getgrnam
+  (error "You need a version of SBCL with SB-POSIX:GETGRNAM \(1.0.10.31 or higher)."))
